"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeScriptPackageGenerator = void 0;
const node_path_1 = __importDefault(require("node:path"));
const circleci_1 = require("../circleci");
const code_analysis_1 = require("../code-analysis");
const eslint_1 = require("../eslint");
const git_1 = require("../git");
const index_1 = require("../github/index");
const gitignore_1 = require("../gitignore");
const node_module_1 = require("../node-module");
const shared_1 = require("../shared");
const testing_1 = require("../testing");
const typescript_1 = require("../typescript");
class TypeScriptPackageGenerator extends shared_1.BaseGenerator {
    constructor(args, options) {
        super(args, options, { customInstallTask: true });
        this.configureSubGenerators = () => {
            return [
                {
                    Generator: gitignore_1.GitignoreGenerator,
                    path: node_path_1.default.join(__dirname, "../gitignore"),
                },
                {
                    Generator: node_module_1.NodeModuleGenerator,
                    path: node_path_1.default.join(__dirname, "../node-module"),
                },
                {
                    Generator: typescript_1.TypeScriptGenerator,
                    path: node_path_1.default.join(__dirname, "../typescript"),
                },
                {
                    Generator: eslint_1.EsLintGenerator,
                    path: node_path_1.default.join(__dirname, "../eslint"),
                },
                {
                    Generator: testing_1.TestingGenerator,
                    path: node_path_1.default.join(__dirname, "../testing"),
                },
                {
                    Generator: git_1.GitGenerator,
                    path: node_path_1.default.join(__dirname, "../git"),
                },
                {
                    Generator: circleci_1.CircleCiGenerator,
                    path: node_path_1.default.join(__dirname, "../circleci"),
                },
                {
                    Generator: code_analysis_1.CodeAnalysisGenerator,
                    path: node_path_1.default.join(__dirname, "../code-analysis"),
                },
                {
                    Generator: index_1.GitHubGenerator,
                    path: node_path_1.default.join(__dirname, "../github"),
                },
            ];
        };
        if (this.options.config) {
            this.loadConfig(this.options.config);
        }
    }
    static getQuestions() {
        return [
            ...node_module_1.NodeModuleGenerator.getQuestions(),
            ...index_1.GitHubGenerator.getQuestions(),
        ];
    }
    writing() {
        return;
    }
}
exports.TypeScriptPackageGenerator = TypeScriptPackageGenerator;
//# sourceMappingURL=TypeScriptPackageGenerator.js.map