"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitGenerator = void 0;
const node_path_1 = __importDefault(require("node:path"));
const package_json_1 = __importDefault(require("../../package.json"));
const shared_1 = require("../shared");
const git_hooks_1 = __importDefault(require("./git-hooks"));
class GitGenerator extends shared_1.BaseGenerator {
    constructor() {
        super(...arguments);
        this.configureSubGenerators = () => {
            return [
                {
                    Generator: git_hooks_1.default,
                    path: node_path_1.default.join(__dirname, "./git-hooks"),
                },
            ];
        };
    }
    static generateCommitMessage() {
        return `Add/update files generated by ${package_json_1.default.name} v${package_json_1.default.version}`;
    }
    async writing() {
        await this.exec("git init");
        if (this.options.configGitUser === true) {
            await this.exec("git config user.email daniel@chiubaka.com");
            await this.exec('git config user.name "Daniel Chiu"');
        }
    }
    async end() {
        const commitMessage = GitGenerator.generateCommitMessage();
        await this.exec("git add .");
        await this.exec(`git commit -m "${commitMessage}" --no-verify`);
    }
}
exports.GitGenerator = GitGenerator;
//# sourceMappingURL=GitGenerator.js.map